@@ -976,7 +976,25 @@ def expand_user(path):
     return pathlib.Path(path).expanduser()
         
 
+# Ignore snapshots with exact same timestamp
+# . Edge cases that can happen and muck up stuff
+# . Handles list(of Snapshot) and list(of tuple(of idx, Snapshot))
+def removeDuplicateSnapshotsByDate(snapshots):
+    _ret = []
+    for i, snap_rec in enumerate(snapshots):
+        if isinstance(snap_rec, Snapshot):
+            snap = snap_rec
+        elif isinstance(snap_rec, tuple):
+            (idx, snap) = snap_rec
+        else:
+            raise Exception(f"Invalid snapshot list passed. Got {type(snap_rec)} at record {i}")
 
+        if i > 0 and snap.creation == snap_last.creation: continue
+
+        _ret.append(snap_rec)
+
+        snap_last = snap
+    return _ret
 
 
 ''' END Utilities '''
